@@ -8,6 +8,9 @@ test_that("AnyCharMatch works and opposite", {
   expect_equal(o3, 3L)
   o3 <- AnyCharMatch(x, "a", FALSE)
   expect_equal(o3, 3L)
+  xx <- c("aa", "aa", "ab")
+  o3 <- AnyCharMatch(xx, "aa", opposite = TRUE)
+  expect_equal(o3, 3L)
 })
 
 test_that("Works fine with NA", {
@@ -17,6 +20,7 @@ test_that("Works fine with NA", {
   expect_equal(AnyCharMatch(x, NA_character_), 3L)
   expect_equal(AnyCharMatch(x, "", opposite = TRUE), 3L)
   expect_equal(AnyCharMatch(x, "a", opposite = TRUE), 1L)
+  expect_equal(AnyCharMatch(x, c("", "a", "b"), opposite = TRUE), 2L)
   expect_equal(AnyCharMatch(x, NA_character_, opposite = TRUE), 1L)
 
   y <- c(NA, "", "")
